@@ -88,7 +88,7 @@ def find_optimset(diagnostic_headers_file, diagnostic_paths_file, gzip_flag):
                             'search',
                          ]
     #Find the list of center / model with all the months for all the years / experiments and variables requested:
-    paths_dict=experiment_years.intersection(paths_dict,diag_tree_desc,diag_tree_desc_final)
+    #paths_dict=experiment_years.intersection(paths_dict,diag_tree_desc,diag_tree_desc_final)
     
     #Write dictionary to file using JSON encoding. If the gzip flag was used,
     #output directly to a compressed file:
